@@ -3,7 +3,7 @@ def exclude_val(data, key, value):
     check if certain key has certain value, return False if so and True otherwise
     """
     # try to get value variable from parser specific variables
-    value = _ttp_["parser_object"].vars.get(value, value)
+    value = _ttp_["vars"].get(value, value)
     try:
         if data[key] == value:
             return data, False
