@@ -1,9 +1,9 @@
 def count(data, var=None, globvar=None):
     if var:
         try:
-            _ttp_["parser_object"].vars[var] += 1
+            _ttp_["vars"][var] += 1
         except KeyError:
-            _ttp_["parser_object"].vars[var] = 1
+            _ttp_["vars"][var] = 1
 
     if globvar:
         try:
