@@ -1,4 +1,4 @@
 def record(data, record):
-    _ttp_["parser_object"].vars.update({record: data})
+    _ttp_["vars"].update({record: data})
     _ttp_["global_vars"].update({record: data})
-    return data, None
\ No newline at end of file
+    return data, None
