@@ -1,9 +1,8 @@
-_name_map_ = {
-"set_func": "set"
-}
+_name_map_ = {"set_func": "set"}
+
 
 def set_func(data, value, match_line):
-    vars = _ttp_["parser_object"].vars
+    vars = _ttp_["vars"]
     if data.rstrip() == match_line:
         if isinstance(value, str):
             if value in vars:
@@ -12,4 +11,4 @@ def set_func(data, value, match_line):
                 return _ttp_["global_vars"][value], None
         return value, None
     else:
-        return data, False
\ No newline at end of file
+        return data, False
