@@ -16,6 +16,7 @@ can increase execution time.
 YANGSON git repository tools/python/mkylib.py script can be used to generates
 YANG JSON library of YANG modules used for validation.
 """
+
 import logging
 import json
 import os
@@ -106,14 +107,14 @@ def _make_library(ydir):
         ) as yf:
             _module_entry(yf)
     marr = []
-    for (yam, mrev) in modmap:
+    for yam, mrev in modmap:
         men = {"name": yam, "revision": mrev}
         sarr = []
         mrec = modmap[(yam, mrev)]
         men["namespace"] = mrec["namespace"]
         fts = mrec["features"]
         imp_only = mrec["import-only"]
-        for (subm, srev) in mrec["includes"]:
+        for subm, srev in mrec["includes"]:
             sen = {"name": subm}
             try:
                 srec = submodmap[subm]
