@@ -33,15 +33,7 @@ def terminal_returner(data, **kwargs):
         for yeallow_word in yellow_words:
             data = data.replace(yeallow_word, fttr.format(Y, yeallow_word, N))
     # print output
-    if _ttp_["python_major_version"] is 2:
-        if isinstance(data, str) or isinstance(
-            data, unicode
-        ):  # pylint: disable=undefined-variable
-            print(data)
-        else:
-            print(str(data).replace("\\n", "\n"))
-    elif _ttp_["python_major_version"] is 3:
-        if isinstance(data, str):
-            print(data)
-        else:
-            print(str(data).replace("\\n", "\n"))
+    if isinstance(data, str):
+        print(data)
+    else:
+        print(str(data).replace("\\n", "\n"))
